@@ -1,7 +1,7 @@
 #
 package Pod::Weaver::Plugin::Include::Finder;
 
-our $VERSION = 'v0.1.8';
+our $VERSION = 'v0.1.9';
 
 # ABSTRACT: Finds source Pods in .pod files or modules.
 
@@ -140,7 +140,7 @@ sub parse_tmpl {
                 )
                 \s*$
 ## Please see file perltidy.ERR
-            /xn;
+            /x;
 
         if ( $+{name} ) {
             $attrs->{name}   = $+{name};
@@ -291,7 +291,7 @@ Pod::Weaver::Plugin::Include::Finder - Finds source Pods in .pod files or module
 
 =head1 VERSION
 
-version v0.1.8
+version v0.1.9
 
 =head1 SYNOPSIS
 
@@ -430,10 +430,9 @@ Vadim Belman <vrurg@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Vadim Belman.
+This software is copyright (c) 2017 by Vadim Belman.
 
-This is free software, licensed under:
-
-  The Apache License, Version 2.0, January 2004
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
